( cd usr/share/doc/HTML/en/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/en/gwenview ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libgwenviewcore.so.1 )
( cd usr/lib ; ln -sf libgwenviewcore.so.1.0.0 libgwenviewcore.so.1 )
( cd usr/lib ; rm -rf libgwenviewcore.so )
( cd usr/lib ; ln -sf libgwenviewcore.so.1.0.0 libgwenviewcore.so )
