<!DOCTYPE kpartgui>
<kpartgui name="GVImagePart" version="6">
<MenuBar>
 <Menu name="file"><Text>&amp;File</Text>
  <Action name="saveAs"/>
 </Menu>
 <Menu name="edit">
  <Action name="rotate_left"/>
  <Action name="rotate_right"/>
 </Menu>
 <Menu name="view"><Text>&amp;View</Text>
  <Separator/>
    <Menu name="colors">
        <text>&amp;Colors</text>
        <Action name="increase_gamma"/>
        <Action name="decrease_gamma"/>
        <Action name="increase_brightness"/>
        <Action name="decrease_brightness"/>
        <Action name="increase_contrast"/>
        <Action name="decrease_contrast"/>
    </Menu>
  <Action name="view_zoom_to_fit"/>
  <Action name="view_zoom_to_width"/>
  <Action name="view_zoom_to_height"/>
  <Action name="view_zoom_in"/>
  <Action name="view_zoom_out"/>
  <Action name="view_actual_size"/>
  <Action name="view_zoom_lock"/>
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
 <Action name="previous"/>
 <Action name="next"/>
 <Action name="view_zoom_in"/>
 <Action name="view_zoom_to"/>
 <Action name="view_zoom_out"/>
 <Action name="rotate_left"/>
 <Action name="rotate_right"/>
</ToolBar>
</kpartgui>
